==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebThemeControllerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebThemeControllerDescription } from "./WebThemeControllerDescription";
/**
 * @hidden
 */
export let WebThemeControllerDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebThemeControllerDescriptionMetadata extends Base {
        static b(a) {
            if (WebThemeControllerDescriptionMetadata.a == null) {
                WebThemeControllerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebThemeControllerDescriptionMetadata.c(WebThemeControllerDescriptionMetadata.a);
            }
            if (a.j(WebThemeControllerDescriptionMetadata.a)) {
                return;
            }
            a.y(WebThemeControllerDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ThemeController");
        }
        static d(a) {
            WebThemeControllerDescriptionMetadata.b(a);
            a.aa("WebThemeController", () => new WebThemeControllerDescription());
            a.z("WebThemeController", WebThemeControllerDescriptionMetadata.a);
        }
    }
    WebThemeControllerDescriptionMetadata.$t = /*@__PURE__*/ markType(WebThemeControllerDescriptionMetadata, 'WebThemeControllerDescriptionMetadata');
    WebThemeControllerDescriptionMetadata.a = null;
    return WebThemeControllerDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebThemeControllerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebThemeControllerDescription } from "./WebThemeControllerDescription";
/**
 * @hidden
 */
export let WebThemeControllerDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebThemeControllerDescriptionMetadata extends Base {
        static b(a) {
            if (WebThemeControllerDescriptionMetadata.a == null) {
                WebThemeControllerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebThemeControllerDescriptionMetadata.c(WebThemeControllerDescriptionMetadata.a);
            }
            if (a.k(WebThemeControllerDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebThemeControllerDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ThemeController");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebThemeControllerDescriptionMetadata.b(a);
            a.ac("WebThemeController", () => new WebThemeControllerDescription());
            a.ab("WebThemeController", WebThemeControllerDescriptionMetadata.a);
        }
    }
    WebThemeControllerDescriptionMetadata.$t = /*@__PURE__*/ markType(WebThemeControllerDescriptionMetadata, 'WebThemeControllerDescriptionMetadata');
    WebThemeControllerDescriptionMetadata.a = null;
    return WebThemeControllerDescriptionMetadata;
})();
